Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: tools/PictureResultsWriter.h

Issue 347823004: Remove Sk prefix from some bench classes. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: SkGMBench -> GMBench Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/PictureBenchmark.h ('k') | tools/bbh_shootout.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/PictureResultsWriter.h
diff --git a/tools/PictureResultsWriter.h b/tools/PictureResultsWriter.h
index 272a50c4c3dcd9ddaa5db91d639939efc9dfe3ac..d4a15765f0325415e6bfebdcb075fa1b0a727a37 100644
--- a/tools/PictureResultsWriter.h
+++ b/tools/PictureResultsWriter.h
@@ -6,15 +6,17 @@
*
* Classes for writing out bench results in various formats.
*/
+
#ifndef SkPictureResultsWriter_DEFINED
#define SkPictureResultsWriter_DEFINED
+#include "BenchLogger.h"
#include "ResultsWriter.h"
-#include "SkBenchLogger.h"
#include "SkJSONCPP.h"
#include "SkStream.h"
#include "SkString.h"
#include "SkTArray.h"
+#include "TimerData.h"
/**
* Base class for writing picture bench results.
@@ -93,7 +95,7 @@ private:
};
/**
* Writes to SkBenchLogger to mimic original behavior
*/
class PictureResultsLoggerWriter : public PictureResultsWriter {
private:
@@ -103,7 +105,7 @@ private:
}
}
public:
- PictureResultsLoggerWriter(SkBenchLogger* log)
+ PictureResultsLoggerWriter(BenchLogger* log)
: fLogger(log), currentLine() {}
virtual void bench(const char name[], int32_t x, int32_t y) {
SkString result;
@@ -136,7 +138,7 @@ public:
}
virtual void end() {}
private:
- SkBenchLogger* fLogger;
+ BenchLogger* fLogger;
SkString currentLine;
};
« no previous file with comments | « tools/PictureBenchmark.h ('k') | tools/bbh_shootout.cpp » ('j') | no next file with comments »
@@ -93,7 +95,7 @@ private:
};
/**
- * Writes to SkBenchLogger to mimic original behavior
+ * Writes to BenchLogger to mimic original behavior
*/
class PictureResultsLoggerWriter : public PictureResultsWriter {

Powered by Google App Engine
This is Rietveld 408576698